==> liquid-xp-54.0.0.jar: src/mods/immibis/lxp/MedallionItem.java <==
package mods.immibis.lxp;

import java.util.List;

import net.minecraft.client.renderer.texture.IconRegister;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.Icon;
import cpw.mods.fml.common.registry.LanguageRegistry;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;

public class MedallionItem extends Item {
	public static final int MAX_STACK = 4;
	
	public MedallionItem(int i) {
		super(i);
		
		setCreativeTab(CreativeTabs.tabMisc);
		LanguageRegistry.addName(new ItemStack(this, 1, 0), "Empty medallion");
		LanguageRegistry.addName(new ItemStack(this, 1, 1), "Glowing medallion");
		
		setHasSubtypes(true);
		
		setCreativeTab(CreativeTabs.tabMisc);
		
		setMaxStackSize(MAX_STACK);
	}
	
	private Icon iGlowing, iBlank;
	
	@Override
	@SideOnly(Side.CLIENT)
	public void updateIcons(IconRegister reg) {
		iGlowing = reg.registerIcon("immibis/lxp:mglowing");
		iBlank = reg.registerIcon("immibis/lxp:mblank");
	}
	
	@SuppressWarnings({ "unchecked", "rawtypes" })
	@Override
	@SideOnly(Side.CLIENT)
	public void getSubItems(int par1, CreativeTabs par2CreativeTabs, List par3List) {
		par3List.add(new ItemStack(this, 1, 0));
		par3List.add(new ItemStack(this, 1, 1));
		par3List.add(new ItemStack(this, 1, 5));
		par3List.add(new ItemStack(this, 1, 10));
		par3List.add(new ItemStack(this, 1, 20));
		par3List.add(new ItemStack(this, 1, 30));
	}
	
	@Override
	@SideOnly(Side.CLIENT)
	public Icon getIconFromDamage(int par1) {
		return (par1 == 0 ? iBlank : iGlowing);
	}
	
	@Override
	public String getUnlocalizedName(ItemStack par1ItemStack) {
		return "immibis.lxp.medallion."+(par1ItemStack.getItemDamage() != 0 ? "charged" : "blank");
	}
	
	@SuppressWarnings({ "unchecked", "rawtypes" })
	@Override
	@SideOnly(Side.CLIENT)
	public void addInformation(ItemStack par1ItemStack, EntityPlayer par2EntityPlayer, List par3List, boolean par4) {
		super.addInformation(par1ItemStack, par2EntityPlayer, par3List, par4);
		
		if(par1ItemStack.getItemDamage() != 0)
			par3List.add("Level "+par1ItemStack.getItemDamage());
	}
}

==> liquid-xp-56.0.2.jar: src/mods/immibis/lxp/MedallionItem.java <==
package mods.immibis.lxp;

import java.util.List;

import net.minecraft.client.renderer.texture.IconRegister;
import net.minecraft.client.resources.I18n;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.Icon;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;

public class MedallionItem extends Item {
	public static final int MAX_STACK = 4;
	
	public MedallionItem(int i) {
		super(i);
		
		setHasSubtypes(true);
		setCreativeTab(LiquidXPMod.tab);
		setMaxStackSize(MAX_STACK);
	}
	
	private Icon iGlowing, iBlank;
	
	@Override
	@SideOnly(Side.CLIENT)
	public void registerIcons(IconRegister reg) {
		iGlowing = reg.registerIcon(R.item.mglowing);
		iBlank = reg.registerIcon(R.item.mblank);
	}
	
	@SuppressWarnings({ "unchecked", "rawtypes" })
	@Override
	@SideOnly(Side.CLIENT)
	public void getSubItems(int par1, CreativeTabs par2CreativeTabs, List par3List) {
		par3List.add(new ItemStack(this, 1, 0));
		par3List.add(new ItemStack(this, 1, 1));
		par3List.add(new ItemStack(this, 1, 5));
		par3List.add(new ItemStack(this, 1, 10));
		par3List.add(new ItemStack(this, 1, 20));
		par3List.add(new ItemStack(this, 1, 30));
	}
	
	@Override
	@SideOnly(Side.CLIENT)
	public Icon getIconFromDamage(int par1) {
		return (par1 == 0 ? iBlank : iGlowing);
	}
	
	@Override
	public String getUnlocalizedName(ItemStack par1ItemStack) {
		return "item.liquidxp.medallion."+(par1ItemStack.getItemDamage() != 0 ? "charged" : "empty");
	}
	
	@SuppressWarnings({ "unchecked", "rawtypes" })
	@Override
	@SideOnly(Side.CLIENT)
	public void addInformation(ItemStack par1ItemStack, EntityPlayer par2EntityPlayer, List par3List, boolean par4) {
		super.addInformation(par1ItemStack, par2EntityPlayer, par3List, par4);
		
		if(par1ItemStack.getItemDamage() != 0)
			par3List.add(I18n.func_135052_a("item.liquidxp.medallion.level", par1ItemStack.getItemDamage()));
	}
}
